@@ -34,8 +34,8 @@ our $MUNIN_LOGDIR     = q{/var/log/munin};
 our $MUNIN_STATEDIR   = q{/var/run/munin};
 our $MUNIN_USER       = q{_munin};
 our $MUNIN_GROUP      = q{_munin};
-our $MUNIN_PLUGINUSER = q{nobody};
-our $MUNIN_VERSION    = q{2.0.18};
+our $MUNIN_PLUGINUSER = q{_munin-plugin};
+our $MUNIN_VERSION    = q{2.0.21};
 our $MUNIN_PERL       = q{/usr/bin/perl};
 our $MUNIN_PERLLIB    = q{/usr/local/libdata/perl5/site_perl};
 our $MUNIN_GOODSH     = q{/bin/sh};
